@@ -1,5 +1,5 @@
 /* cfg.h --- Configuration file functions.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -24,8 +24,6 @@
 /* Get prototypes. */
 #include "cfg.h"
 
-#include "getsubopt.h"
-
 #define KDC_SERVICE_PORT "\x6b\x65\x72\x62\x65\x72\x6f\x73"
 
 enum
@@ -277,11 +275,11 @@ shishi_cfg (Shishi * handle, char *option)
 		  {
 		    *p = '\0';
 		    p++;
-		    if (strcmp (p, "udp") == 0)
+		    if (strcasecmp (p, "udp") == 0)
 		      protocol = UDP;
-		    else if (strcmp (p, "tcp") == 0)
+		    else if (strcasecmp (p, "tcp") == 0)
 		      protocol = TCP;
-		    else if (strcmp (p, "tls") == 0)
+		    else if (strcasecmp (p, "tls") == 0)
 		      protocol = TLS;
 		    else
 		      shishi_warn (handle,
