@@ -1,5 +1,5 @@
 /* internal.h --- Internal header file for Shishi.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -101,16 +101,11 @@
 
 #include "gettext.h"
 
-#include "vasprintf.h"
 #include "xvasprintf.h"
 #include "base64.h"
 #include "getdate.h"
 #include "getline.h"
 #include "read-file.h"
-#include "strtok_r.h"
-#include "time_r.h"
-#include "timegm.h"
-#include "vasprintf.h"
 #include "xalloc.h"
 #include "xgethostname.h"
 #include "xgetdomainname.h"
@@ -198,6 +193,7 @@ struct Shishi
   char *tktsdefaultfile;
   char *ccachedefault;
   char *hostkeysdefaultfile;
+  char *x509cafile;
   char *x509certfile;
   char *x509keyfile;
   char *stringprocess;
