@@ -24,27 +24,25 @@
 /**
  * shishi_principal_default_guess:
  *
- * Guesses a principal using getpwuid(getuid)), or if it fails, the
+ * Guesses the principal name for the user, looking at environment
+ * variables SHISHI_USER and USER, or if that fails, returns the
  * string "user".
  *
- * Return value: Returns guessed default principal for user as a string that
- * has to be deallocated with free() by the caller.
+ * Return value: Returns guessed default principal for user as a
+ * string that has to be deallocated with free() by the caller.
  **/
 char *
 shishi_principal_default_guess (void)
 {
-#if HAVE_GETPWUID
-  uid_t uid;
-  struct passwd *pw;
+  char *envuser;
 
-  uid = getuid ();
-  pw = getpwuid (uid);
+  envuser = getenv ("SHISHI_USER");
+  if (!envuser)
+    envuser = getenv ("USER");
+  if (!envuser)
+    envuser = "user";
 
-  if (pw && pw->pw_name)
-    return xstrdup (pw->pw_name);
-  else
-#endif
-    return xstrdup ("user");
+  return xstrdup (envuser);
 }
 
 
@@ -52,9 +50,9 @@ shishi_principal_default_guess (void)
  * shishi_principal_default:
  * @handle: Shishi library handle create by shishi_init().
  *
- * The default principal name is the name returned from
- * getpwuid(getuid) but can be overridden by specifying the
- * environment variable SHISHI_USER.
+ * The default principal name is the name in the environment variable
+ * USER, but can be overridden by specifying the environment variable
+ * SHISHI_USER.
  *
  * Return value: Returns the default principal name used in the
  * library.  (Not a copy of it, so don't modify or deallocate it.)
@@ -62,12 +60,6 @@ shishi_principal_default_guess (void)
 const char *
 shishi_principal_default (Shishi * handle)
 {
-  char *envuser;
-
-  envuser = getenv ("SHISHI_USER");
-  if (envuser)
-    return envuser;
-
   if (!handle->default_principal)
     {
       char *p;
@@ -299,8 +291,8 @@ shishi_principal_name_realm (Shishi * handle,
       char *realm;
       size_t realmlen;
 
-      rc =
-	shishi_asn1_read (handle, realmnode, realmfield, &realm, &realmlen);
+      rc = shishi_asn1_read (handle, realmnode, realmfield,
+			     &realm, &realmlen);
       if (rc != SHISHI_OK)
 	{
 	  free (tmp);
@@ -315,6 +307,8 @@ shishi_principal_name_realm (Shishi * handle,
       tmplen += 1 + realmlen;
 
       tmp[tmplen] = '\0';
+
+      free (realm);
     }
 
   *out = tmp;
