@@ -1,5 +1,5 @@
 /* kdc.h --- Header file with common definitions for Shishid.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -123,9 +123,6 @@ extern int errno;
 /* Get xmalloc. */
 #include "xalloc.h"
 
-/* Get asprintf. */
-#include "vasprintf.h"
-
 /* Shishi and Shisa library. */
 #include <shishi.h>
 #include <shisa.h>
