@@ -1,5 +1,5 @@
 /* shishi.c --- Shishi command line interface.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -45,9 +45,6 @@
 /* Get set_program_name and program_name. */
 #include "progname.h"
 
-/* Get asprintf. */
-#include "vasprintf.h"
-
 /* Get error. */
 #include "error.h"
 
